---
last_modified_on: "2020-04-11"
component_title: "Add Fields"
description: "The Vector `add_fields` transform accepts and outputs `log` events allowing you to add one or more log fields."
event_types: ["log"]
function_category: "shape"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_fields%22
sidebar_label: "add_fields|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/add_fields.rs
status: "prod-ready"
title: "Add Fields Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `add_fields` transform
accepts and outputs [`log`][docs.data-model.log] events allowing you to add one
or more log fields.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/add_fields.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "add_fields" # required
  inputs = ["my-source-id"] # required

  # Fields
  fields.string_field = "string value" # example
  fields.env_var_field = "${ENV_VAR}" # example
  fields.templated_field = "{{ my_other_field }}" # example
  fields.int_field = 1 # example
  fields.float_field = 1.2 # example
  fields.bool_field = true # example
  fields.timestamp_field = 1979-05-27T00:32:00Z # example
  fields.parent.child_field = "child_value" # example
  fields.list_field = ["first", "second", "third"] # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "add_fields" # required
  inputs = ["my-source-id"] # required

  # Fields
  fields.string_field = "string value" # example
  fields.env_var_field = "${ENV_VAR}" # example
  fields.templated_field = "{{ my_other_field }}" # example
  fields.int_field = 1 # example
  fields.float_field = 1.2 # example
  fields.bool_field = true # example
  fields.timestamp_field = 1979-05-27T00:32:00Z # example
  fields.parent.child_field = "child_value" # example
  fields.list_field = ["first", "second", "third"] # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### fields

A table of key/value pairs representing the keys to be added to the event.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"string_field":"string value"},{"env_var_field":"${ENV_VAR}"},{"templated_field":"{{ my_other_field }}"},{"int_field":1},{"float_field":1.2},{"bool_field":true},{"timestamp_field":"1979-05-27 00:32:00 -0700"},{"parent":{"child_field":"child_value"}},{"list_field":["first","second","third"]}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"fields"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"*"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

The name of the field to add. Accepts all [supported
types][docs.configuration#types]. Use `.` for adding nested fields.




</Field>
</Fields>

</Field>
</Fields>

## How It Works

### Complex Processing

If you encounter limitations with the `add_fields`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Conflicts

#### Key Conflicts

Keys specified in this transform will replace existing keys.

#### Nested Key Conflicts

Nested keys are added in a _deep_ fashion. They will not replace any ancestor
objects. For example, given the following `log` event:

```javascript
{
  "parent": {
    "child1": "value1"
  }
}
```

And the following configuration:

```toml
[transforms.add_nested_field]
  type = "add_fields"
  fields.parent.child2 = "value2"
```

Will result in the following log event:

```javascript
{
  "parent": {
    "child1": "value1",
    "child2": "value2"
  }
}
```

Notice that `parent.child1` field was preserved.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Types

All supported [configuration value types][docs.configuration#types] are
accepted. This includes primitivate types (`string`, `int`, `float`, `boolean`)
and special types, such as [arrays](#arrays) and
[nested fields](#nested-fields).


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.configuration#types]: /docs/setup/configuration/#types
[docs.data-model.log]: /docs/about/data-model/log/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
