---
last_modified_on: "2020-04-11"
component_title: "GeoIP"
description: "The Vector [`geoip`](#geoip) transform accepts and outputs `log` events allowing you to enrich events with geolocation data from the MaxMind GeoIP2 and GeoLite2 city databases."
event_types: ["log"]
function_category: "enrich"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+geoip%22
sidebar_label: "geoip|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/geoip.rs
status: "beta"
title: "GeoIP Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector [`geoip`](#geoip) transform
accepts and outputs [`log`][docs.data-model.log] events allowing you to enrich
events with geolocation data from the MaxMind GeoIP2 and GeoLite2 city
databases.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/geoip.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "geoip" # required
  inputs = ["my-source-id"] # required
  database = "/path/to/GeoLite2-City.mmdb" # required
  source = "ip_address" # required
  target = "geoip" # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "geoip" # required
  inputs = ["my-source-id"] # required
  database = "/path/to/GeoLite2-City.mmdb" # required
  source = "ip_address" # required
  target = "geoip" # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/GeoLite2-City.mmdb"]}
  groups={[]}
  name={"database"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### database

Path to the MaxMind GeoIP2 or GeoLite2 binary city database file
(`GeoLite2-City.mmdb`). Other databases, such as the the country database are
not supported.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["ip_address","x-forwarded-for","parent.child","array[0]"]}
  groups={[]}
  name={"source"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### source

The field name that contains the IP address. This field should contain a valid
IPv4 or IPv6 address.

 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={"geoip"}
  enumValues={null}
  examples={["geoip","parent.child"]}
  groups={[]}
  name={"target"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### target

The default field to insert the resulting GeoIP data into. See
[output](#output) for more info.

 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
</Fields>

## Fields

```javascript title="example log event"
{
  // ...
  "geoip": {
    "city_name": "New York",
    "continent_code": "AF",
    "country_code": "US",
    "latitude": "51.75",
    "longitude": "-1.25",
    "postal_code": "07094",
    "timezone": "America/New_York"
  }
  // ...
}
```

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"geoip"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"struct"}
  unit={null}
  warnings={[]}
  >

### geoip

The root field containing all geolocation data as sub-fields.

 See [Complex Processing](#complex-processing) for more info.

<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["New York","Brooklyn","Chicago"]}
  groups={[]}
  name={"city_name"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### city_name

The city name associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"AF":"Africa","AN":"Antarctica","AS":"Asia","EU":"Europe","NA":"North America","OC":"Oceania","SA":"South America"}}
  examples={["AF","AN","AS","EU","NA","OC","SA"]}
  groups={[]}
  name={"continent_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### continent_code

The continent code associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["US","US-PR","FR","FR-BL","GB","A1","A2"]}
  groups={[]}
  name={"country_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### country_code

The [ISO 3166-2 country codes][urls.iso3166-2] associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["51.75"]}
  groups={[]}
  name={"latitude"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### latitude

The latitude associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["-1.25"]}
  groups={[]}
  name={"longitude"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### longitude

The longitude associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["07094","10010","OX1"]}
  groups={[]}
  name={"postal_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### postal_code

The postal code associated with the IP address.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["America/New_York","Asia/Atyrau","Europe/London"]}
  groups={[]}
  name={"timezone"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### timezone

The timezone associated with the IP address in [IANA time zone
format][urls.iana_time_zone_format]. A full list of time zones can be found
[here][urls.iana_time_zones].




</Field>
</Fields>

</Field>
</Fields>

## How It Works

### Complex Processing

If you encounter limitations with the [`geoip`](#geoip)
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`source`](#source) and [`target`](#target) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_geoip_transform_id]
  # ...
  source = "ip_address"
  source = "x-forwarded-for"
  source = "parent.child"
  source = "array[0]"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[urls.iana_time_zone_format]: https://en.wikipedia.org/wiki/Tz_database#Names_of_time_zones
[urls.iana_time_zones]: https://en.wikipedia.org/wiki/List_of_tz_database_time_zones
[urls.iso3166-2]: https://en.wikipedia.org/wiki/ISO_3166-2
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
