---
last_modified_on: "2020-04-16"
title: Install Vector via DPKG
sidebar_label: DPKG
description: Install Vector through the DKG package manager
---

import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import Jump from '@site/src/components/Jump';
import Steps from '@site/src/components/Steps';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Vector can be installed through the [DPKG package manager][urls.dpkg] which is
generally used on Debian and Ubuntu systems.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/package-managers/dpkg.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="daemon"
  values={[{"label":"As a Daemon","value":"daemon"}]}>
<TabItem value="daemon">

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
Typically data is collected from a process manager, such as Journald via
Vector's [`journald` source][docs.sources.journald], but can be collected
through any of Vector's [sources][docs.sources].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={null}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"dpkg"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Package managers","label":"DPKG","value":"dpkg"}]}>
<TabItem value="dpkg">

<Tabs
  centered={true}
  className="rounded"
  defaultValue="x86_64"
  values={[{"label":"x86_64","value":"x86_64"},{"label":"ARM64","value":"arm64"},{"label":"ARMv7","value":"armv7"}]}>

<TabItem value="x86_64">
<Steps headingDepth={3}>
<ol>
<li>

### Download the Vector `.deb` package

```bash
curl --proto '=https' --tlsv1.2 -O https://packages.timber.io/vector/0.9.X/vector-amd64.deb
```

[Looking for a different version?][docs.package_managers.dpkg#versions]

</li>
<li>

### Install the downloaded package

```bash
sudo dpkg -i vector-amd64.deb
```

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"journald"}
  sinkName={null} />

</li>
<li>

### Start Vector

```bash
sudo systemctl start vector
```

</li>
</ol>
</Steps>
</TabItem>
<TabItem value="arm64">
<Steps headingDepth={3}>
<ol>
<li>

### Download the Vector `.deb` package

```bash
curl --proto '=https' --tlsv1.2 -O https://packages.timber.io/vector/0.9.X/vector-arm64.deb
```

[Looking for a different version?][docs.package_managers.dpkg#versions]

</li>
<li>

### Install the downloaded package

```bash
sudo dpkg -i vector-arm64.deb
```

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"journald"}
  sinkName={null} />

</li>
<li>

### Start Vector

```bash
sudo systemctl start vector
```

</li>
</ol>
</Steps>
</TabItem>
<TabItem value="armv7">
<Steps headingDepth={3}>
<ol>
<li>

### Download the Vector `.deb` package

```bash
curl --proto '=https' --tlsv1.2 -O https://packages.timber.io/vector/0.9.X/vector-armhf.deb
```

[Looking for a different version?][docs.package_managers.dpkg#versions]

</li>
<li>

### Install the downloaded package

```bash
sudo dpkg -i vector-armhf.deb
```

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"journald"}
  sinkName={null} />

</li>
<li>

### Start Vector

```bash
sudo systemctl start vector
```

</li>
</ol>
</Steps>
</TabItem>
</Tabs>

</TabItem>
</Tabs>
</TabItem>
</Tabs>

## Configuring

The Vector configuration file is located at:

```text
etc/vector/vector.toml
```

A full spec is located at `/etc/vector/vector.spec.toml` and examples are
located in `/etc/vector/examples/*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

## Deploying

How you deploy Vector is largely dependent on your use case and environment.
Please see the [deployment section][docs.deployment] for more info on how to
deploy Vector.

## Administering

Vector can be managed through the [Systemd][urls.systemd] service manager:

<Jump to="/docs/administration/">Administration</Jump>

## Uninstalling

```bash
sudo dpkg -r vector
```

## Updating

Follow the [install](#install) steps again, downloading the
[latest version](#latest-version) of Vector.

## Package

### Architectures

Vector's DPKG packages are multi-arch and support the
x86_64, ARM64, and ARMv7
architectures. The architecture name is prepended to the artifact file name.

### Versions

Vector's DPKG packages can be downloaded with the following URLs. Note that
Vector maintains special URLS that are automatically updated whenever Vector is
[released][urls.vector_releases]:

<Tabs
  className="mini"
  defaultValue="x86_64"
  values={[{"label":"x86_64","value":"x86_64"},{"label":"ARM64","value":"ARM64"},{"label":"ARMv7","value":"ARMv7"}]}>
<TabItem value="x86_64">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-amd64.deb`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-amd64.deb`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-amd64.deb`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-amd64.deb`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-amd64.deb`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-amd64.deb` |

</TabItem>
<TabItem value="ARM64">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-arm64.deb`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-arm64.deb`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-arm64.deb`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-arm64.deb`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-arm64.deb`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-arm64.deb` |

</TabItem>
<TabItem value="ARMv7">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-armhf.deb`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-armhf.deb`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-armhf.deb`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-armhf.deb`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-armhf.deb`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-armhf.deb` |

</TabItem>
</Tabs>


### Source Files

Vector's DPKG source files are located in
[Vector's repo][urls.vector_debian_source_files].


[docs.configuration]: /docs/setup/configuration/
[docs.deployment]: /docs/setup/deployment/
[docs.package_managers.dpkg#versions]: /docs/setup/installation/package-managers/dpkg/#versions
[docs.sources.journald]: /docs/reference/sources/journald/
[docs.sources]: /docs/reference/sources/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[urls.dpkg]: https://wiki.debian.org/dpkg
[urls.systemd]: https://systemd.io/
[urls.vector_debian_source_files]: https://github.com/timberio/vector/tree/master/distribution/debian
[urls.vector_releases]: https://vector.dev/releases/latest/
