---
last_modified_on: "2020-04-16"
title: Install Vector via RPM
sidebar_label: RPM
description: Install Vector through the RPM package manager
---

import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import Jump from '@site/src/components/Jump';
import Steps from '@site/src/components/Steps';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Vector can be installed through the [RPM package manager][urls.rpm] which is
generally used on CentOS.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/package-managers/rpm.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="daemon"
  values={[{"label":"As a Daemon","value":"daemon"}]}>
<TabItem value="daemon">

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
Typically data is collected from a process manager, such as Journald via
Vector's [`journald` source][docs.sources.journald], but can be collected
through any of Vector's [sources][docs.sources].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={null}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"rpm"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Package managers","label":"RPM","value":"rpm"}]}>
<TabItem value="rpm">

<Steps headingDepth={3}>
<Tabs
  centered={true}
  className="rounded"
  defaultValue="arm64"
  values={[{"label":"ARM64","value":"arm64"},{"label":"ARMv7","value":"armv7"},{"label":"x86_64","value":"x86_64"}]}>

<TabItem value="arm64">

1.  ### Download the Vector `.rpm` file

    ```bash
    curl -O https://packages.timber.io/vector/0.9.X/vector-aarch64.rpm
    ```

    [Looking for a specific version?][docs.package_managers.rpm#versions]

2.  ### Install the Vector `.rpm` package directly

    ```bash
    sudo rpm -i vector-aarch64.rpm
    ```

3.  ### Configure Vector

    <ConfigExample
      format="toml"
      path={"/etc/vector/vector.toml"}
      sourceName={"journald"}
      sinkName={null} />

4.  ### Start Vector

    ```bash
    sudo systemctl start vector
    ```

</TabItem>
<TabItem value="armv7">

1.  ### Download the Vector `.rpm` file

    ```bash
    curl -O https://packages.timber.io/vector/0.9.X/vector-armv7hl.rpm
    ```

    [Looking for a specific version?][docs.package_managers.rpm#versions]

2.  ### Install the Vector `.rpm` package directly

    ```bash
    sudo rpm -i vector-armv7hl.rpm
    ```

3.  ### Configure Vector

    <ConfigExample
      format="toml"
      path={"/etc/vector/vector.toml"}
      sourceName={"journald"}
      sinkName={null} />

4.  ### Start Vector

    ```bash
    sudo systemctl start vector
    ```

</TabItem>
<TabItem value="x86_64">

1.  ### Download the Vector `.rpm` file

    ```bash
    curl -O https://packages.timber.io/vector/0.9.X/vector-x86_64.rpm
    ```

    [Looking for a specific version?][docs.package_managers.rpm#versions]

2.  ### Install the Vector `.rpm` package directly

    ```bash
    sudo rpm -i vector-x86_64.rpm
    ```

3.  ### Configure Vector

    <ConfigExample
      format="toml"
      path={"/etc/vector/vector.toml"}
      sourceName={"journald"}
      sinkName={null} />

4.  ### Start Vector

    ```bash
    sudo systemctl start vector
    ```

</TabItem>
</Tabs>
</Steps>

</TabItem>
</Tabs>
</TabItem>
</Tabs>

## Configuring

The Vector configuration file is placed in:

```text
etc/vector/vector.toml
```

A full spec is located at `/etc/vector/vector.spec.toml` and examples are
located in `/etc/vector/examples/*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

## Deploying

How you deploy Vector is largely dependent on your use case and environment.
Please see the [deployment section][docs.deployment] for more info on how to
deploy Vector.

## Administering

Vector can be managed through the [Systemd][urls.systemd] service manager:

<Jump to="/docs/administration/">Administration</Jump>

## Uninstalling

```bash
sudo rpm -e vector
```

## Updating

Follow the [install](#install) steps again, downloading the latest version of
Vector.

## Package

### Architectures

Vector's RPM packages are multi-arch and support the
x86_64
architectures. The architecture name is prepended to the artifact file name.

### Versions

Vector's RPM packages can be downloaded with the following URLs. Note that
Vector maintains special URLS that are automatically updated whenever Vector is
[released][urls.vector_releases]:

<Tabs
  className="mini"
  defaultValue="ARM64"
  values={[{"label":"ARM64","value":"ARM64"},{"label":"ARMv7","value":"ARMv7"},{"label":"x86_64","value":"x86_64"}]}>
<TabItem value="ARM64">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-aarch64.rpm`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-aarch64.rpm`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-aarch64.rpm`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-aarch64.rpm`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-aarch64.rpm`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-aarch64.rpm` |

</TabItem>
<TabItem value="ARMv7">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-armv7hl.rpm`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-armv7hl.rpm`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-armv7hl.rpm`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-armv7hl.rpm`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-armv7hl.rpm`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-armv7hl.rpm` |

</TabItem>
<TabItem value="x86_64">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-x86_64.rpm`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-x86_64.rpm`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-x86_64.rpm`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-x86_64.rpm`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-x86_64.rpm`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-x86_64.rpm` |

</TabItem>
</Tabs>


### Source Files

Vector's RPM source files are located in
[Vector's repo][urls.vector_rpm_source_files].


[docs.configuration]: /docs/setup/configuration/
[docs.deployment]: /docs/setup/deployment/
[docs.package_managers.rpm#versions]: /docs/setup/installation/package-managers/rpm/#versions
[docs.sources.journald]: /docs/reference/sources/journald/
[docs.sources]: /docs/reference/sources/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[urls.rpm]: https://rpm.org/
[urls.systemd]: https://systemd.io/
[urls.vector_releases]: https://vector.dev/releases/latest/
[urls.vector_rpm_source_files]: https://github.com/timberio/vector/tree/master/distribution/rpm
